import {request} from "@/utils/request.js"

//获取首页banner栏内容
export function apiGetBanner(){
	return request({
		url:"/homeBanner",
	})

}

//获取首页每日推荐栏内容
export function apiGetDayRandom(){
	return request({url:"/randomWall"})

} 

//获取首页公告栏内容
export function apiGetNotice(data={}){
	return request({
		url:"/wallNewsList",
		data
	})
}

//获取tabBar的“分类”里面的列表内容
export function apiGetClassify(data={}){
	return request({
		url:"/classify",
		data
	})
}


//获取tabBar的“分类”栏里面给一个板块的具体图片内容
export function apiGetClassList(data={}){
	return request({
		url:"/wallList",
		data
	})
}

//为每一个壁纸评分
export function apiGetSetScore(data={}){
	return request({
		url:"/setupScore",
		data
	})
}

//下载壁纸
export function apiWriteDownload(data={}){
	return request({
		url:"/downloadWall",
		data
	})
}

// 判断用户是不是通过别人分享进来的，从而获取被分享壁纸的详情信息。只有一张
export function apiDetailWall(data={}){
	return request({
		url:"/detailWall",
		data
	})
}

//获取 “我的” 页面的个人信息
export function apiUserInfo(data={}){
	return request({
		url:"/userInfo",
		data
	})
}

//获取 “我的” 页面中"我的下载"和"我的评分"的区分信息
export function apiGetHistoryList(data={}){
	return request({
		url:"/userWallList",
		data
	})
}

//获取 “我的” 页面中"我的下载"和"我的评分"的区分信息
export function apiNoticeDetail(data={}){
	return request({
		url:"/wallNewsDetail",
		data
	})
}

//获取 “搜索”页面 壁纸信息
export function apiSearchData(data={}){
	return request({
		url:"/searchWall",
		data
	})
}
